bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGamma.add_plate_axis
=======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGamma.add_plate_axis